Installation
============

Installation & setup:
---------------------
``sedpy`` is pip installable:

.. code-block:: shell

		python -m pip install astro-sedpy

Or you can install the latest version from github:

.. code-block:: shell

		git clone https://github.com/bd-j/sedpy
		cd sedpy
		pip install .
